Description Usage Arguments Details Value Author(s) Examples
perc can be used to extract percentiles from the sampling
distribution of a statistic.
1 2 |
boot.out |
Output from either |
p |
numeric vector with values in [0, 1]. |
lm.boot.obj |
An object of class |
perc automatically calls perc.lm if boot.out is
of the class "lm.simpleboot" so there is no need to use
perc.lm separately.
For bootstraps which are not linear model bootstraps, perc
returns a vector of percentiles of length
length(p). Linear interpolation of percentiles is done if
necessary. perc.lm returns a matrix of percentiles
of each of the model coefficients. For example, if there are k model
coefficients, the perc.lm returns a length(p) by k matrix.
Roger D. Peng
1 2 3 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.